pub fn start_stream(unique_id: &str) -> Result<CameraStream, CaptureError>Expand description
Start a live capture stream on the camera with unique_id.
Errors
Same as capture_frame, minus Timeout (frames are polled, not awaited).
pub fn start_stream(unique_id: &str) -> Result<CameraStream, CaptureError>Start a live capture stream on the camera with unique_id.
Same as capture_frame, minus Timeout (frames are polled, not awaited).